#!/bin/sh
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

if [ -z "$1" ]; then
  cd "$(dirname "$0")"
  cd plugins
else
  cd "$1"
fi

for plugin_dir in $(ls -d */build.sh); do
  echo "Building remote plugin: $plugin_dir" &&\
  $plugin_dir
  exit_code=$?
  if [ $exit_code != 0 ]; then
    exit $exit_code
  fi
done
